"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const openai_1 = __importDefault(require("openai"));
const context_1 = require("./context");
const gradient_1 = require("./gradient");
exports.default = async (apiKey, prompt, opts) => {
    const apiKeyValue = await apiKey;
    const openai = new openai_1.default({ apiKey: apiKeyValue });
    const spinner = (0, gradient_1.loadWithRocketGradient)("Thinking...").start();
    (0, context_1.addContext)({
        role: "system",
        content: "Read the context, when returning the answer , always wrapping block of code exactly within triple backticks ",
    });
    (0, context_1.addContext)({ role: "user", content: prompt });
    const request = await openai.chat.completions
        .create({
        model: opts.engine || "gpt-4-1106-preview",
        messages: (0, context_1.getContext)(),
        temperature: opts.temperature ? Number(opts.temperature) : 1,
    })
        .then((res) => {
        if (typeof res.choices[0].message !== "undefined") {
            (0, context_1.addContext)(res.choices[0].message);
            spinner.stop();
            return res.choices[0].message;
        }
        else {
            throw new Error("Undefined messages received");
        }
    })
        .catch((err) => {
        spinner.stop();
        switch (err["response"]["status"]) {
            case 404:
                throw new Error(`${chalk_1.default.red("Not Found: Model not found. Please check the model name.")}`);
            case 429:
                throw new Error(`${chalk_1.default.red("API Rate Limit Exceeded: ChatGPT is getting too many requests from the user in a short period of time. Please wait a while before sending another message.")}`);
            case 400:
                throw new Error(`${chalk_1.default.red("Bad Request: Prompt provided is empty or too long. Prompt should be between 1 and 4096 tokens.")}`);
            case 402:
                throw new Error(`${chalk_1.default.red("Payment Required: ChatGPT quota exceeded. Please check you chatGPT account.")}`);
            case 503:
                throw new Error(`${chalk_1.default.red("Service Unavailable: ChatGPT is currently unavailable, possibly due to maintenance or high traffic. Please try again later.")}`);
            default:
                throw new Error(`${err}`);
        }
    });
    if (request === undefined || !request?.content) {
        throw new Error("Undefined request or content");
    }
    return request;
};
