#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const process_1 = __importDefault(require("process"));
const prompts_1 = __importDefault(require("prompts"));
const intro_1 = __importDefault(require("./intro"));
const utils_1 = require("./utils");
const encrypt_1 = require("./encrypt");
const c = __importStar(require("commander"));
const commander = new c.Command();
commander
    .command("chat")
    .option("-e, --engine <engine>", "GPT model to use")
    .option("-t, --temperature <temperature>", "Response temperature")
    .option("-m, --markdown", "Show markdown in the terminal")
    .usage(`"<project-directory>" [options]`)
    .action(async (opts) => {
    (0, intro_1.default)();
    (0, utils_1.apiKeyPrompt)()
        .then((apiKey) => {
        const prompt = async () => {
            const response = await (0, prompts_1.default)({
                type: "text",
                name: "value",
                message: `${chalk_1.default.blueBright("You: ")}`,
                validate: () => {
                    return true;
                },
                onState: (state) => {
                    if (state.aborted) {
                        process_1.default.exit(0);
                    }
                }
            });
            switch (response.value) {
                case "exit":
                    return process_1.default.exit(0);
                case "clear":
                    return process_1.default.stdout.write("\x1Bc");
                default:
                    if (apiKey != null) {
                        (0, utils_1.generateResponse)(apiKey, prompt, response, opts);
                    }
                    return;
            }
        };
        prompt();
    });
});
// create commander to delete api key
commander
    .command("delete")
    .description("Delete your API key")
    .action(async () => {
    const response = await (0, prompts_1.default)({
        type: "select",
        name: "value",
        message: "Are you sure?",
        choices: [
            { title: "Yes", value: "yes" },
            { title: "No - exit", value: "no" },
        ],
        initial: 0,
    });
    if (response.value) {
        return process_1.default.exit(0);
    }
    (0, encrypt_1.deleteApiKey)();
    console.log("API key deleted");
});
commander
    .command("endpoint")
    .option("--set <url>", "Set your custom endpoint")
    .option("-r, --reset", "Reset the API endpoint to default ")
    .description("Configure your API endpoint")
    .action(async () => {
    console.log("Send empty to set default openai endpoint");
    (0, prompts_1.default)({
        type: "text",
        name: "value",
        validate: (t) => t.search(/(https?:\/(\/.)+).*/g) === 0 || t === "" ? true : "Urls only allowed",
        message: "Insert endpoint: "
    })
        .then(response => response.value
        .replace('/chat/completions', ''))
        .then(value => /(https?:\/(\/.)+).*/g.test(value) ? value : undefined)
        .then(encrypt_1.saveCustomUrl);
});
commander.parse(process_1.default.argv);
