"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateResponse = exports.apiKeyPrompt = void 0;
const clipboard = __importStar(require("clipboardy"));
const encrypt_1 = require("./encrypt");
const prompts_1 = __importDefault(require("prompts"));
const chalk_1 = __importDefault(require("chalk"));
const process = __importStar(require("process"));
const marked_1 = require("marked");
const marked_terminal_1 = __importDefault(require("marked-terminal"));
const gpt_1 = __importDefault(require("./gpt"));
marked_1.marked.setOptions({
    // Define custom renderer
    renderer: new marked_terminal_1.default(),
});
async function apiKeyPrompt() {
    let apiKey = (0, encrypt_1.getApiKey)();
    if (!apiKey) {
        const response = await (0, prompts_1.default)({
            type: "password",
            name: "apiKey",
            message: "Enter your OpenAI API key:",
            validate: (value) => {
                return value !== "";
            },
        });
        apiKey = response.apiKey;
        (0, encrypt_1.saveApiKey)((0, encrypt_1.encrypt)(response.apiKey));
    }
    return apiKey;
}
exports.apiKeyPrompt = apiKeyPrompt;
async function checkBlockOfCode(text) {
    // get all matches of text within ```
    const regex = /```[\s\S]*?```/g;
    const matches = text.match(regex);
    if (matches) {
        const recentTextNoBackticks = matches[0].replace(/```/g, "");
        const response = await (0, prompts_1.default)({
            type: "confirm",
            name: "copy",
            message: `Copy recent code to clipboard?`,
            initial: true,
        });
        if (response.copy) {
            clipboard.writeSync(recentTextNoBackticks);
        }
    }
}
async function generateResponse(apiKey, prompt, response, opts) {
    try {
        const request = await (0, gpt_1.default)(apiKey, response.value, opts);
        if (request === undefined || !request?.content) {
            throw new Error("Undefined request or content");
        }
        // map all choices to text
        const getText = [request.content];
        console.log(`${chalk_1.default.cyan("GPT: ")}`);
        if (opts.markdown) {
            const markedText = marked_1.marked.parse(getText[0]);
            let i = 0;
            const interval = setInterval(() => {
                if (i < markedText.length) {
                    process.stdout.write(markedText[i]);
                    i++;
                }
                else {
                    clearInterval(interval);
                    process.stdout.write("\n"); // Add this line
                    checkBlockOfCode(markedText).then(prompt);
                }
            }, 10);
        }
        else {
            // console log each character of the text with a delay and then call prompt when it finished
            let i = 0;
            const interval = setInterval(() => {
                if (i < getText[0].length) {
                    process.stdout.write(getText[0][i]);
                    i++;
                }
                else {
                    clearInterval(interval);
                    process.stdout.write("\n"); // Add this line
                    checkBlockOfCode(getText[0]).then(prompt);
                }
            }, 10);
        }
    }
    catch (err) {
        console.error(`${chalk_1.default.red("Something went wrong!!")} ${err}`);
        // create a prompt of type select , with the options to exit or try again
        const response = await (0, prompts_1.default)({
            type: "select",
            name: "value",
            message: "Try again?",
            choices: [
                { title: "Yes", value: "yes" },
                { title: "No - exit", value: "no" },
            ],
            initial: 0,
        });
        if (response.value == "no") {
            return process.exit(0);
        }
        generateResponse(apiKey, prompt, response, opts);
    }
}
exports.generateResponse = generateResponse;
